# Logging & Security — Django Developer Reference

- [logit App](logit.md) — Database logging via the Log model
- [Incident System](incidents.md) — Security events, rule engine, fleet-wide IP blocking, OSSEC integration
